CoinMetadata

Struct CoinMetadata 

#[non_exhaustive]
pub struct CoinMetadata { pub id: Option<ObjectId>, pub decimals: Option<u32>, pub name: Option<String>, pub symbol: Option<String>, pub description: Option<String>, pub icon_url: Option<String>, pub metadata_cap_id: Option<ObjectId>, pub metadata_cap_state: Option<i32>, }
Metadata for a coin type

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<ObjectId>

ObjectId of the 0x2::coin::CoinMetadata object or 0x2::iota::coin_registry::Currency object (when registered with CoinRegistry).

decimals: Option<u32>

Number of decimal places the coin uses.

name: Option<String>

Name for the token

symbol: Option<String>

Symbol for the token

description: Option<String>

Description of the token

icon_url: Option<String>

URL for the token logo

metadata_cap_id: Option<ObjectId>

The MetadataCap ID if it has been claimed for this coin type. This capability allows updating the coin’s metadata fields. Only populated when metadata is from CoinRegistry.

metadata_cap_state: Option<i32>

State of the MetadataCap for this coin type.

Implementations

Source

impl CoinMetadata

Source

impl CoinMetadata

Source

impl CoinMetadata

pub fn with_id<T: Into<ObjectId>>(self, field: T) -> Self

Sets id with the provided value.

pub fn with_decimals(self, field: u32) -> Self

Sets decimals with the provided value.

pub fn with_name<T: Into<String>>(self, field: T) -> Self

Sets name with the provided value.

pub fn with_symbol<T: Into<String>>(self, field: T) -> Self

Sets symbol with the provided value.

pub fn with_description<T: Into<String>>(self, field: T) -> Self

Sets description with the provided value.

pub fn with_icon_url<T: Into<String>>(self, field: T) -> Self

Sets icon_url with the provided value.

pub fn with_metadata_cap_id<T: Into<ObjectId>>(self, field: T) -> Self

Sets metadata_cap_id with the provided value.

pub fn with_metadata_cap_state(self, field: MetadataCapState) -> Self

Sets metadata_cap_state with the provided value.

Source

impl CoinMetadata

pub fn decimals(&self) -> u32

Returns the value of decimals, or the default value if decimals is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.

pub fn icon_url(&self) -> &str

Returns the value of icon_url, or the default value if icon_url is unset.

pub fn metadata_cap_state(&self) -> MetadataCapState

Returns the enum value of metadata_cap_state, or the default if the field is unset or set to an invalid enum value.

pub fn set_metadata_cap_state(&mut self, value: MetadataCapState)

Sets metadata_cap_state to the provided enum value.