CoinTreasury

Struct CoinTreasury 

#[non_exhaustive]
pub struct CoinTreasury { pub id: Option<ObjectId>, pub total_supply: Option<u64>, pub supply_state: Option<i32>, }
Information about a coin type’s 0x2::coin::TreasuryCap and its total available supply

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<ObjectId>

ObjectId of the 0x2::coin::TreasuryCap object.

total_supply: Option<u64>

Total available supply for this coin type.

supply_state: Option<i32>

Supply state indicating if the supply is fixed or can still be minted

Implementations

Source

impl CoinTreasury

Source

impl CoinTreasury

Source

impl CoinTreasury

pub fn with_id<T: Into<ObjectId>>(self, field: T) -> Self

Sets id with the provided value.

pub fn with_total_supply(self, field: u64) -> Self

Sets total_supply with the provided value.

pub fn with_supply_state(self, field: SupplyState) -> Self

Sets supply_state with the provided value.

Source

impl CoinTreasury

pub fn total_supply(&self) -> u64

Returns the value of total_supply, or the default value if total_supply is unset.

pub fn supply_state(&self) -> SupplyState

Returns the enum value of supply_state, or the default if the field is unset or set to an invalid enum value.

pub fn set_supply_state(&mut self, value: SupplyState)

Sets supply_state to the provided enum value.