RegulatedCoinMetadata

Struct RegulatedCoinMetadata 

#[non_exhaustive]
pub struct RegulatedCoinMetadata { pub id: Option<ObjectId>, pub coin_metadata_object: Option<ObjectId>, pub deny_cap_object: Option<ObjectId>, pub allow_global_pause: Option<bool>, pub variant: Option<u32>, pub coin_regulated_state: Option<i32>, }
Information about a regulated coin, which indicates that it makes use of the transfer deny list.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<ObjectId>

ObjectId of the 0x2::coin::RegulatedCoinMetadata object. Only present for coins that have not been migrated to CoinRegistry.

coin_metadata_object: Option<ObjectId>

The ID of the coin’s CoinMetadata or CoinData object.

deny_cap_object: Option<ObjectId>

The ID of the coin’s DenyCap object.

allow_global_pause: Option<bool>

Whether the coin can be globally paused

variant: Option<u32>

Variant of the regulated coin metadata

coin_regulated_state: Option<i32>

Indicates the coin’s regulated state.

Implementations

Source

impl RegulatedCoinMetadata

Source

impl RegulatedCoinMetadata

Source

impl RegulatedCoinMetadata

pub fn with_id<T: Into<ObjectId>>(self, field: T) -> Self

Sets id with the provided value.

pub fn with_coin_metadata_object<T: Into<ObjectId>>(self, field: T) -> Self

Sets coin_metadata_object with the provided value.

pub fn with_deny_cap_object<T: Into<ObjectId>>(self, field: T) -> Self

Sets deny_cap_object with the provided value.

pub fn with_allow_global_pause(self, field: bool) -> Self

Sets allow_global_pause with the provided value.

pub fn with_variant(self, field: u32) -> Self

Sets variant with the provided value.

pub fn with_coin_regulated_state(self, field: CoinRegulatedState) -> Self

Sets coin_regulated_state with the provided value.

Source

impl RegulatedCoinMetadata

pub fn allow_global_pause(&self) -> bool

Returns the value of allow_global_pause, or the default value if allow_global_pause is unset.

pub fn variant(&self) -> u32

Returns the value of variant, or the default value if variant is unset.

pub fn coin_regulated_state(&self) -> CoinRegulatedState

Returns the enum value of coin_regulated_state, or the default if the field is unset or set to an invalid enum value.

pub fn set_coin_regulated_state(&mut self, value: CoinRegulatedState)

Sets coin_regulated_state to the provided enum value.